﻿-- SeeCD core
-- v 1.1
-- Author Granduca


---
local _, L = ...;
local SECD = L;


---
local defaults = {
	frx = (UIParent:GetWidth() / 2),
	fry = -(UIParent:GetHeight() / 2),
	flag1 = 0,
	flag2 = 1,
	inst_bg = 1,
	inst_ar = 0,
	movePanels = true,
	dir = "right",
	SeeCDsfontSize = L["s_dd2 mid"],
	SeeCDsfSize = 2,
	SeeCDsdirName = L["s_dd1 right"],
	SeeCDsdir = 3,
	i_size = 32,
	i_offset = 1,
	i_alpha = 0.75,
	a_alpha = 0.04,
	a_scale = 0.9,
	shDesc = true,
	specIcon = true,
	zcb1 = false,
	zcb2 = true,
	zcb3 = true,
	zcb4 = false,
}


---
local sdb = {}
local sedb = {}
local specdb = {}
local textStyles = {
	normal = {
		r = 0.2, g = 1, b= 0, a = 1,
	},
	few = {
		r = 0.7, g = 1, b= 0, a = 1,
	},
	soon = {
		r = 1, g = 0, b= 0, a = 1,
	},
}
local tar_factor_width = 10
local SeeCDsfont = "Fonts\\FRIZQT__.TTF"
local t_size
local gname
local t_trinket = "Interface\\Icons\\Inv_jewelry_trinketpvp_01.png‎"
local isI
local inT
L.f1 = 0
L.f2 = 0
L.f3 = 0
L.f4 = 0
L.cFirst = 0
L.fewTime = 10
L.soonTime = 5


---
local function OnEvent(self, event, ...)

 if event == "COMBAT_LOG_EVENT_UNFILTERED" then
	local args = {...}
	if SECD.db.specIcon == true then
		SECD.DetectSpecByArgs(args)
	end
	SECD.checkFlags(args[6])
	if L.SeeCDs[args[12]] and L.f1 ~= 0 and L.f2 ~= 0 and L.f3 ~= 0 and L.f4 ~= 0 then
		local uname = strmatch(args[5], "[%P]+")
		if args[2] == "SPELL_CAST_SUCCESS" or args[2] == "SPELL_AURA_APPLIED" or args[2] == "SPELL_MISSED" or args[2] == "SPELL_SUMMON" then
			if not sdb[uname] then sdb[uname] = {} end
			if not sdb[uname][args[13]] or GetTime() >= sdb[uname][args[13]] + 1 then
--				print(args[13])
				SECD.createIcon(uname, args[12], args[13])
				sdb[uname][args[13]] = GetTime()
			end
		end
	end
 end

 if event == "PLAYER_TARGET_CHANGED" then
	local name = select(1,UnitName("playertarget"))
	if SECD.db.specIcon == true then
		if name ~= nil then
			SECD.SpecFrame:Hide()
			SECD.SpecDetector()
			SECD.UpdateIconByName(name, specdb[name])
		else
			SECD.SpecFrame:Hide()
			specDescHide()
		end
	end
	clearIcons()
	if sedb[name] ~= nil then
 		if name == nil then
			clearIcons()
		else
			addIcons(name)
		end
	end
 end

 if event == "PLAYER_ENTERING_WORLD" then
	wipe(sdb)
	wipe(sedb)
	wipe(specdb)
	gname = nil
	if L.cFirst ~= 1 then
		if not SeeCDB then
			SeeCDB = {}
		end
		DEFAULT_CHAT_FRAME:AddMessage("|cFFFFCC00" .. L["welcome"])
		SECD.db = SECD.CopyDefaults(defaults, SeeCDB)
		SECD.createFrames()
		SECD.CreateConfig()
		SECD.createTestFrame()
		SECD.S.checkbox1:SetChecked(SECD.db.movePanels)
		SECD.S.checkbox2:SetChecked(SECD.db.shDesc)
		SECD.S.checkbox3:SetChecked(SECD.db.specIcon)
		UIDropDownMenu_SetText(SECD.dropdown1, SECD.db.SeeCDsdirName)
		UIDropDownMenu_SetText(SECD.dropdown2, SECD.db.SeeCDsfontSize)
		SECD.slider1:SetValue(SECD.db.i_size)
		SECD.slider2:SetValue(SECD.db.i_offset)
		SECD.slider3:SetValue(SECD.db.i_alpha)
		SECD.slider4:SetValue(SECD.db.a_alpha)
		SECD.slider5:SetValue(SECD.db.a_scale)
		SECD.Z.checkbox1:SetChecked(SECD.db.zcb1)
		SECD.Z.checkbox2:SetChecked(SECD.db.zcb2)
		SECD.Z.checkbox3:SetChecked(SECD.db.zcb3)
		SECD.Z.checkbox4:SetChecked(SECD.db.zcb4)
		L.cFirst = 1
	end
	SECD.removeFrames()
	SECD.createFrames()
	SECD.createTestFrame()
	local isInstance, instanceType = IsInInstance()
	isI = isInstance
	inT = instanceType
	SECD.checkFlags1()
	SECD.targetFrame:EnableMouse(SECD.db.movePanels)
 end

end


---
local SeeCD = CreateFrame("Frame")
SeeCD:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED")
SeeCD:RegisterEvent("PLAYER_ENTERING_WORLD")
SeeCD:RegisterEvent("PLAYER_TARGET_CHANGED")
SeeCD:SetScript("OnEvent", OnEvent)


---
CreateFrame("GameTooltip", "DescriptionTooltip", nil, "GameTooltipTemplate");


---
SLASH_SEECD1 = '/seecd'
local function sCmdFunc()
	InterfaceOptionsFrame_OpenToCategory(SECD.S)
end
SlashCmdList["SEECD"] = sCmdFunc;


---
function SECD.createFrames()
	SECD.targetFrame = CreateFrame("frame", nil, UIParent)

	SECD.targetFrame:SetPoint("TOPLEFT", UIParent, "TOPLEFT", SECD.db.frx, SECD.db.fry)

	SECD.targetFrame:SetAlpha(SECD.db.i_alpha)
	SECD.targetFrame:SetWidth(SECD.db.i_size*tar_factor_width)
	SECD.targetFrame:SetHeight(SECD.db.i_size)

	SECD.targetFrame:SetMovable(SECD.db.movePanels)
	SECD.targetFrame:EnableMouse(SECD.db.movePanels)
	SECD.targetFrame:SetScript("OnMouseDown", function(self, button)
		if button == "LeftButton" and not self.isMoving and SECD.db.movePanels ~= false then
			self:StartMoving();
			self.isMoving = true;
			self:SetScript("OnUpdate", function()
				moveFrame(self)
			end)
			SECD.anchorFrame.title:SetText(L["anchor tooltip"])
		end
		if button == "RightButton" then
			SECD.db.movePanels = false
			SECD.targetFrame:SetMovable(false)
			SECD.anchorFrame:Hide()
			SECD.anchorFrame:SetMovable(false)
			SECD.targetFrame:EnableMouse(false)
			SECD.anchorFrame:EnableMouse(false)
			SECD.S.checkbox1:SetChecked(SECD.db.movePanels)
		end
	end)
	SECD.targetFrame:SetScript("OnMouseUp", function(self, button)
		if button == "LeftButton" and self.isMoving then
			self:StopMovingOrSizing();
			self.isMoving = false;
			self:SetScript("OnUpdate", nil)
			SECD.anchorFrame.title:SetText("SeeCD's anchor")
		end
	end)

	SECD.targetFrame:Show()

---
	SECD.anchorFrame = CreateFrame("frame", nil, UIParent)

	SECD.anchorFrame:SetWidth(90)
	SECD.anchorFrame:SetHeight(12)
	SECD.anchorFrame:SetPoint("TOPLEFT", UIParent, "TOPLEFT", SECD.db.frx-SECD.anchorFrame:GetWidth(), SECD.db.fry+SECD.anchorFrame:GetHeight())

	SECD.anchorFrame:SetMovable(SECD.db.movePanels)
	SECD.anchorFrame:EnableMouse(SECD.db.movePanels)
	SECD.anchorFrame:SetScript("OnMouseDown", function(self, button)
		if button == "LeftButton" and not self.isMoving and SECD.db.movePanels ~= false then
			self:StartMoving();
			self.isMoving = true;
			self:SetScript("OnUpdate", function()
				moveFrame(self)
			end)
			self.title:SetText(L["anchor tooltip"])
		end
	end)
	SECD.anchorFrame:SetScript("OnMouseUp", function(self, button)
		if button == "LeftButton" and self.isMoving then
			self:StopMovingOrSizing();
			self.isMoving = false;
			self:SetScript("OnUpdate", nil)
			self.title:SetText("SeeCD's anchor")
		end
		if button == "RightButton" then
			SECD.db.movePanels = false
			SECD.targetFrame:SetMovable(false)
			SECD.anchorFrame:Hide()
			SECD.anchorFrame:SetMovable(false)
			SECD.targetFrame:EnableMouse(false)
			SECD.anchorFrame:EnableMouse(false)
			SECD.S.checkbox1:SetChecked(SECD.db.movePanels)
		end
	end)
	SECD.anchorFrame:SetBackdrop({bgFile = "Interface/Tooltips/UI-Tooltip-Background"});
	SECD.anchorFrame:SetBackdropColor(0,0,0,1);

	SECD.anchorFrame.title = SECD.anchorFrame:CreateFontString(nil, "OVERLAY")
	SECD.anchorFrame.title:SetTextColor(0.7, 1, 0)
	SECD.anchorFrame.title:SetAllPoints(SECD.anchorFrame)
	SECD.anchorFrame.title:SetFont(SeeCDsfont, 10, "OUTLINE")
	SECD.anchorFrame.title:SetText("SeeCD's anchor")

	if SECD.db.movePanels == true then
		SECD.anchorFrame:Show()
	else
		SECD.anchorFrame:Hide()
	end

---
	SECD.anchorFramePoint = CreateFrame("frame", nil, SECD.anchorFrame)

	SECD.anchorFramePoint:SetWidth(4)
	SECD.anchorFramePoint:SetHeight(4)
	SECD.anchorFramePoint:SetPoint("TOPLEFT", SECD.anchorFrame, SECD.anchorFrame:GetWidth()-4, -SECD.anchorFrame:GetHeight()+4)
	SECD.anchorFramePoint:SetBackdrop({bgFile = "Interface/Tooltips/UI-Tooltip-Background"});
	SECD.anchorFramePoint:SetBackdropColor(0.7,1,0,1);
	SECD.anchorFramePoint:Show()

---

	SECD.SpecFrame = CreateFrame("frame", nil, UIParent)

	SECD.chkDir(1)

	SECD.SpecFrame:SetAlpha(SECD.db.i_alpha)
	SECD.SpecFrame:SetWidth(SECD.db.i_size)
	SECD.SpecFrame:SetHeight(SECD.db.i_size)
	SECD.SpecFrame.texture = SECD.SpecFrame:CreateTexture(nil, "BORDER")
	SECD.SpecFrame.texture:SetAllPoints(SECD.SpecFrame)

	SECD.SpecFrame:SetScript("OnUpdate", function(self)
		iconOnUpdate(self, 1)
	end)

	SECD.SpecFrame:Hide()

end


---
function SECD.removeFrames()
	if SECD.targetFrame ~= nil then
		SECD.targetFrame:Hide()
		SECD.targetFrame:SetParent(nil)
		SECD.anchorFrame:Hide()
		SECD.anchorFrame:SetParent(nil)
		SECD.testFrame:Hide()
		SECD.testFrame:SetParent(nil)
		SECD.SpecFrame:Hide()
		SECD.SpecFrame:SetParent(nil)
	end
end


---
function moveFrame(self)
	_, _, _, SECD.db.frx, SECD.db.fry = self:GetPoint()
	if self == SECD.anchorFrame then
		SECD.targetFrame:SetPoint("TOPLEFT", UIParent, "TOPLEFT", SECD.db.frx+SECD.anchorFrame:GetWidth(), SECD.db.fry-SECD.anchorFrame:GetHeight())
	else
		SECD.anchorFrame:SetPoint("TOPLEFT", UIParent, "TOPLEFT", SECD.db.frx-SECD.anchorFrame:GetWidth(), SECD.db.fry+SECD.anchorFrame:GetHeight())
	end
	_, _, _, SECD.db.frx, SECD.db.fry = SECD.targetFrame:GetPoint()
end


---
function SECD.CopyDefaults(src, ssdb)
	if not src then return { } end
	if not ssdb then ssdb = { } end
	for k, v in pairs(src) do
		if type(v) == "table" then
			ssdb[k] = SECD.CopyDefaults(v, ssdb[k])
		elseif type(v) ~= type(ssdb[k]) then
			ssdb[k] = v
		end
	end
	return ssdb
end


---
function SECD.checkFlags(flg)
	if SECD.db.flag1 == 1 then 
		L.f1 = bit.band(flg, COMBATLOG_OBJECT_REACTION_FRIENDLY)
	else
		L.f1 = 0
	end
	if SECD.db.flag2 == 1 then 
		L.f2 = bit.band(flg, COMBATLOG_OBJECT_REACTION_HOSTILE)
	else
		L.f2 = 0
	end
	if L.f1 ~= 0 and L.f2 == 0 then
		L.f2 = 1
	end
	if L.f2 ~= 0 and L.f1 == 0 then
		L.f1 = 1
	end
end
function SECD.checkFlags1()
	if SECD.db.inst_bg == 1 and isI == 1 and inT == pvp then
		L.f3 = 1
	else
		L.f3 = 1
	end
	if SECD.db.inst_bg == 0 and isI == 1 and inT == pvp then
		L.f3 = 0
	else
		L.f3 = 1
	end
	if SECD.db.inst_ar == 1 and isI == 1 and inT == arena then
		L.f4 = 1
	else
		L.f4 = 0
	end
	if SECD.db.inst_ar == 0 and isI == 1 and inT == arena then
		L.f4 = 1
	else
		L.f4 = 1
	end
end


---
function SECD.createIcon(Name, spellID, spellName)
	local sframe
	local t = textStyles.normal
	if not sedb[Name] then sedb[Name] = {} end
	local tname = select(1,UnitName("playertarget"))
	local _, _, texture = GetSpellInfo(spellID)
	if spellID == 42292 then
		texture = t_trinket
	end
	if Name == 'test' then 
		sframe = SECD.testFrame
	else
		sframe = SECD.targetFrame
	end
	local duration = L.SeeCDs[spellID]
	local icon = CreateFrame("frame", nil, sframe)
	icon.texture = icon:CreateTexture(nil, "BORDER")
	icon.texture:SetAllPoints(icon)
	icon.texture:SetTexture(texture)
	icon.endtime = GetTime() + duration
	icon.cooldown = icon:CreateFontString(nil, "OVERLAY")
	icon.cooldown:SetTextColor(t.r,t.g,t.b,t.a)
	icon.cooldown:SetAllPoints(icon)
	icon.name = spellName
	icon.id = spellID
	icon:SetWidth(SECD.db.i_size)
	icon:SetHeight(SECD.db.i_size)
	icon:SetPoint("TOPLEFT", 0, 0)
	icon:Hide()
	for i = 1, #sedb[Name] do
		if sedb[Name][i] then
			if sedb[Name][i].name == spellName then
				sedb[Name][i]:Hide()
				sedb[Name][i]:SetParent(nil)
				tremove(sedb[Name], i)
			end
		end
	end
	tinsert(sedb[Name], icon)
	icon:SetScript("OnUpdate", function(self)
		tracker(Name, self)
		iconOnUpdate(self, 0)
	end)
	if Name == 'test' then
		addIcons(Name)		
	elseif Name == tname then
		clearIcons()
		addIcons(Name)
	end
end


---
function removeIcon(name, icon)
	local tname = select(1,UnitName("playertarget"))
	icon:SetScript("onUpdate", nil)
	icon:Hide()
	icon:SetParent(nil)
	for i=1, #sedb[name] do
		if sedb[name][i] == icon then
			tremove(sedb[name], i)
		end
	end
	if tname ~= nil and name ~= 'test' then
		clearIcons()
		addIcons(tname)
	end
	if name == 'test' then
		clearIcons()
		addIcons(name)
	end
	DescriptionTooltip:Hide()
end


---
function addIcons(name)
	gname = name
	local sframe
	SECD.chkDir(0)
	t_size = ceil(SECD.db.i_size - SECD.db.i_size / SECD.db.SeeCDsfSize)
	for i=1, #sedb[name] do
		sedb[name][i]:ClearAllPoints()
		sedb[name][i]:SetWidth(SECD.db.i_size)
		sedb[name][i]:SetHeight(SECD.db.i_size)
		if name == 'test' then 
			sframe = SECD.testFrame
		else
			sframe = SECD.targetFrame
		end
		sedb[name][i]:SetParent(sframe)
		sedb[name][i].cooldown:SetFont(SeeCDsfont, t_size, "OUTLINE")
		sort(sedb[name], function(a,b) return a.endtime < b.endtime end)
		if i > 1 then
			sedb[name][i]:SetPoint("TOPLEFT", sedb[name][i-1], (SECD.db.i_size + SECD.db.i_offset)*L.x_x, (SECD.db.i_size + SECD.db.i_offset)*L.y_y)
			sedb[name][i]:Show();
		else
			sedb[name][i]:SetPoint("TOPLEFT", 0, 0)
			sedb[name][i]:Show();
		end
	end
end


---
function clearIcons()
	if gname ~= nil then 
		for i=1, #sedb[gname] do
			if gname == 'test' then
				if sedb[gname][i].endtime <= 0 then
					sedb[gname][i]:Hide()
					DescriptionTooltip:Hide()
				end
			else
				sedb[gname][i]:Hide()
				DescriptionTooltip:Hide()
			end
		end
	end
end


---
function animIcon(name, icon)
	local alpha = icon:GetAlpha()
	local scale = icon:GetWidth()
	alpha = alpha - SECD.db.a_alpha
	scale = scale + SECD.db.a_scale
	if alpha <= 0 then
		removeIcon(name, icon)
	end
	icon:SetAlpha(alpha)
	icon:SetWidth(scale)
	icon:SetHeight(scale)
end


---
function tracker(name, icon)
	local tf = textStyles.few
	local ts = textStyles.soon
	local cdtimer = ceil(icon.endtime - GetTime())
	if not t_size then t_size = ceil(SECD.db.i_size - SECD.db.i_size / SECD.db.SeeCDsfSize) end
	if cdtimer >= 60 then
		icon.cooldown:SetFont(SeeCDsfont, t_size, "OUTLINE")
		icon.cooldown:SetText(ceil(cdtimer/60).."m")
	elseif cdtimer < 60 and cdtimer >= 1 then
		icon.cooldown:SetFont(SeeCDsfont, t_size, "OUTLINE")
		icon.cooldown:SetText(cdtimer)
	elseif cdtimer == 0 then
		icon:SetScript("OnUpdate", function()
			animIcon(name, icon)
		end)
	else
		removeIcon(name, icon)
	end
	if cdtimer <= L.fewTime and cdtimer > L.soonTime then
		icon.cooldown:SetFont(SeeCDsfont, (SECD.db.i_size - SECD.db.i_size / SECD.fontsDB[L["s_dd2 large"]]), "OUTLINE")
		icon.cooldown:SetTextColor(tf.r,tf.g,tf.b,tf.a)
	end
	if cdtimer <= L.soonTime then
		icon.cooldown:SetFont(SeeCDsfont ,SECD.db.i_size, "OUTLINE")
		icon.cooldown:SetTextColor(ts.r,ts.g,ts.b,ts.a)
	end
end


---
function iconOnUpdate(self, chk)
	if MouseIsOver(self) then
		if chk == 0 then
			spellDescShow(self.id)
		else
			specDescShow(self.id)
		end
	else
		if chk == 0 then
			spellDescHide(self.id)
		else
			specDescHide()
		end
	end
end


---
function spellDescShow(spellId)
	if SECD.db.shDesc == true then
		DescriptionTooltip:SetOwner(UIParent, "ANCHOR_CURSOR")
		DescriptionTooltip:SetSpellByID(spellId)
		DescriptionTooltip:Show()
	end
end


---
function spellDescHide(spellId)
	_,_,arg3 = DescriptionTooltip:GetSpell()
	if arg3 == spellId then
		DescriptionTooltip:Hide()
	end
end


---
function specDescShow(spec)
	if SECD.db.shDesc == true then
		if SECD.db.specIcon == true then
			if spec ~= nil then
				DescriptionTooltip:SetOwner(UIParent, "ANCHOR_CURSOR")
				DescriptionTooltip:SetText(spec, 1, 1, 0,  1, 1)
				DescriptionTooltip:Show()
			end
		end
	end
end


---
function specDescHide()
	DescriptionTooltip:Hide()
end


---
function SECD.chkDir(d)
	if d == 0 then
		if SECD.db.SeeCDsdir == 0 then
			L.x_x = 0
			L.y_y = 1
			SECD.testFrame:ClearAllPoints()
			SECD.testFrame:SetPoint("RIGHT", SECD.S.button, "RIGHT", 400, -130)
		elseif SECD.db.SeeCDsdir == 1 then
			L.x_x = 0
			L.y_y = -1
			SECD.testFrame:ClearAllPoints()
			SECD.testFrame:SetPoint("RIGHT", SECD.S.button, "RIGHT", 400, -22)
		elseif SECD.db.SeeCDsdir == 2 then
			L.x_x = -1
			L.y_y = 0
			SECD.testFrame:ClearAllPoints()
			SECD.testFrame:SetPoint("RIGHT", SECD.S.button, "RIGHT", 400, -22)
		elseif SECD.db.SeeCDsdir == 3 then
			L.x_x = 1
			L.y_y = 0
			SECD.testFrame:ClearAllPoints()
			SECD.testFrame:SetPoint("RIGHT", SECD.S.button, "RIGHT", 284, -22)
		end
	elseif d == 1 then
		if SECD.db.SeeCDsdir == 0 then
			SECD.SpecFrame:ClearAllPoints()
			SECD.SpecFrame:SetPoint("TOPLEFT", SECD.targetFrame, "TOPLEFT", 0, -SECD.db.i_size)
		elseif SECD.db.SeeCDsdir == 1 then
			SECD.SpecFrame:ClearAllPoints()
			SECD.SpecFrame:SetPoint("TOPLEFT", SECD.targetFrame, "TOPLEFT", 0, SECD.db.i_size)
		elseif SECD.db.SeeCDsdir == 2 then
			SECD.SpecFrame:ClearAllPoints()
			SECD.SpecFrame:SetPoint("TOPLEFT", SECD.targetFrame, "TOPLEFT", SECD.db.i_size, 0)
		elseif SECD.db.SeeCDsdir == 3 then
			SECD.SpecFrame:ClearAllPoints()
			SECD.SpecFrame:SetPoint("TOPLEFT", SECD.targetFrame, "TOPLEFT", -SECD.db.i_size, 0)
		end
	end
end


---
function SECD.SpecDetector()
	local icon
	for i=1,40 do
		local buff = select(11,UnitBuff("target",i))
		local unitCaster = select(8,UnitBuff("target",i))
		if buff ~= nil and unitCaster ~= nil then
			if L.SpecList[buff] then
				SECD.UpdateIconByName(select(1,UnitName(unitCaster)), L.SpecList[buff])
			end
		end
	end
	for i=1,40 do
		local debuff = select(11,UnitDebuff("target",i))
		local unitCaster = select(8,UnitDebuff("target",i))
		if debuff ~= nil and unitCaster ~= nil then
			if L.SpecList[debuff] then
				SECD.UpdateIconByName(select(1,UnitName(unitCaster)), L.SpecList[debuff])
			end
		end
	end
end


---
function SECD.DetectSpecByArgs(args)
	if bit.band(args[6], COMBATLOG_OBJECT_TYPE_PLAYER ) == 0 then return end
	if args[2] == "SPELL_AURA_APPLIED" or args[2] == "SPELL_AURA_REMOVED" or args[2] == "SPELL_AURA_APPLIED_DOSE" or args[2] == "SPELL_AURA_REMOVED_DOSE" or args[2] == "SPELL_AURA_REFRESH" then
		if args[5] ~= nil and L.SpecList[args[12]] ~= nil then
			SECD.UpdateIconByName(strmatch(args[5], "[%P]+"), L.SpecList[args[12]])
		end
	elseif args[2] == "SPELL_CAST_START" or "SPELL_CAST_SUCCESS" then
		if args[5] ~= nil and L.SpecList[args[12]] ~= nil then
			SECD.UpdateIconByName(strmatch(args[5], "[%P]+"), L.SpecList[args[12]])
		end
	end
end	


---
function SECD.UpdateIconByName(name, spec)
	local tname = select(1,UnitName("playertarget"))
	if specdb[name] ~= spec and spec ~= nil then
		specdb[name] = spec
	end
	local icon = L.DetectSpecIcon(specdb[name], "target")
	if icon ~= nil and tname == name then
		local playerClass, _ = UnitClass("target")
		if L.specTip[specdb[tname]] == nil then
			L.SpecFrame.id = playerClass
		else
			L.SpecFrame.id = (playerClass.." - "..L.specTip[specdb[tname]])
		end
		SECD.SpecFrame.texture:SetTexture(icon)
		SECD.SpecFrame:Show()
	end
end